#
# spec file for package rmpc
#
# Copyright (c) 2024 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test
Name:           rmpc
Version:        0.7.0
Release:        1.2
Summary:        Rusty Music Player Client for MPD
License:        BSD-3-Clause
URL:            https://github.com/mierak/rmpc
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  rust >= 1.74
Recommends:     mpd
Recommends:     yt-dlp

%description
RMPC is a beautiful, modern and configurable terminal based Music Player
Daemon client with album art support. It is heavily inspired by ncmpcpp
and ranger/lf file managers.

%prep
%autosetup -a1 -p1

%build
%{cargo_build}

%install
install -Dm755 target/release/%{name} -t %{buildroot}%{_bindir}
install -Dm644 target/man/%{name}.1 -t %{buildroot}%{_mandir}/man1
install -Dm644 target/completions/%{name}.bash -t \
    %{buildroot}%{_datadir}/bash-completion/completions
install -Dm644 target/completions/%{name}.fish -t \
    %{buildroot}%{_datadir}/fish/vendor_completions.d
install -Dm644 target/completions/_%{name} -t \
    %{buildroot}%{_datadir}/zsh/site-functions

%if %{with test}
%check
%{cargo_test} -- \
    --skip=config::utils::tests::home_dir_not_present::_yes_yes_expects
%endif

%files
%license LICEN*
%doc README* CHANGELOG.md
%{_bindir}/%{name}
%{_mandir}/man*/%{name}.*
%{_datadir}/bash-completion/completions
%{_datadir}/fish
%{_datadir}/zsh

%changelog
* Wed Jan  1 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Removed cargo_audit from _service due that contains vendor now
* Wed Jan  1 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.7.0
  + Added
  - JumpToCurrent Queue action to make the cursor jump to the
    currently playing song
  - Mouse support for modal popups
  - List available decoder plugins from MPD via ShowDecoders
    action or rmpc decoders
  - Ability to add and instantly play song under cursor. Bound
    to Confirm action
  - Theme: add symbols.ellipsis to customize the ellipsis when
    text need to be truncated
  - A new Lyrics pane used to display synchronized lyrics.
  - Missing default keybind for the Album Artists tab
  - Allow stop action to work in paused state
  - Select functionality to the queue, selected songs can be
    moved up and down in the queue at the same time using the
    MoveUp/Down actions
  - Selected songs in queue can now be removed all at once from
    the Queue with the Delete action
  - InvertSelection action
  - Show album date in the Artists and AlbumArtists panes
  - Config options to sort albums by date or name and to hide or
    show album date in in the Artists and AlbumArtists panes
  - Rmpc will now try to reconnect and reinitialize on losing
    connection to mpd
  + Changed
  - Queue table now remembers cursor position when you switch
    tabs
  - Browser panes now remember cursor position in the root level
    when you switch tabs
  - Refactor and split utils module
  - Set binary limit to 5MB
  - Disabled album arts for songs over http(s). Can be brought
    back by changing album_art.disabled_protocols
  - Improves the usability and clarity of the queue deletion
    confirmation modal
  - width_percent config option in song_table_format. Replaced by
    width.
  - Deletion of a playlist now requires user confirmation
  - Default keybinds for tabs to make space for the Album
    Artists tab
  - Swapped default single and consume keybinds
  - Clear album art and song in the header when the playback
    stops
  - Refactored confirm modal into a generic one
  - Refactored rename playlist and save queue modal into a
    generic modal with single input
  - Refactored add to playlist modal into generic select modal
  - Refactored MPD client out of a UI thread. Rmpc now also
    requires only single connection to MPD.
  + Fixed
  - Songs not being sorted below directories in the Directories
    pane
  - Scrolloff issues in Playlists pane after rename/move
  - Few typos in UI and internal messages
  - Click to select and rendering issues in SongInfo and Decoder
    modals
  - Read stream not being emptied after encountering error while
    reading MPD's response
  - Rows not wrapping in the keybinds modal when the screen is
    too small
  - Unchecked panic inside the volume widget when volume exceeds
    certain value
  - Several things that should have happened on song change were
    happening on every Player event, ie. seeking
  - Improved handling of errors while reading MPD's response
  - Adjust scrollbar position in browser panes when track symbol
    is empty
  - Scrolloff not applying on the very first render
  + Deprecated
  - width_percent config option in song_table_format. It will
    continue to work for now, but will be removed in the future.
* Mon Oct 28 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.6.0
  + Added
  - Arrow keys as secondary navigation keybinds alongside hjkl
  - Support for basic control with mouse.
  - Scrolloff option to keep some context the various
    lists/tables
  - Update/rescan CLI commands to refresh MPD's database
  - Support MPD password via config, env vars and CLI
  - ShowInfo action to queue pane. Displays metadata of the song
    under cursor in a modal popup.
  - ShowCurrentSongInfo global action. Displays metadata of the
    song currently playing song in a modal popup.
  + Changed
  - Removed left/right arrows as default keybinds for
    next/previous tab.
  - Filtering is now incremental
  - Up/Down actions do not wrap around anymore.
  - Allow seeking while paused
  + Fixed
  - Rmpc now logs warnings and errors in CLI mode to stderr
  - try to clean up after yt-dlp in case it fails
  - Album art not clearing properly after direct tab switch
  - Events being duplicated when panes were present in multiple
    tabs
  - Ueberzugpp redrawing album art while in an inactive TMUX
    window/session
  - Fix improper scrollbar rendering with some symbols being empty
  - Removed duplicated tags in metadata view of a song
* Fri Sep 27 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.5.0
  + Fixed
  - allow negative one in status.volume
  - Do not query album art when it is disabled
  - browser column zero width, make docs wider
  - skip unnecessary album art work and fix some overdraws when
    changing screens
  - always print CARGO_PKG_VERSION
  - improve logging of mpd parse failures
* Wed Aug 28 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Change license from MIT to BSD-3-Clause
* Mon Aug 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- skip config::utils::tests::home_dir_not_present::_yes_yes_expects
  on test unit, its make build failed on Factory
* Fri Jun 21 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
